stylist — Stylist 0.3.dev1 documentation

# stylist

Extensible code style checker currently supporting Fortran, PSyclone DSL, etc

Exceptions

`StylistException` | Allows exceptions from stylist to be distinguished from other exceptions.

exception stylist.StylistException

  Bases: `Exception`

  Allows exceptions from stylist to be distinguished from other exceptions.

Modules

`stylist.configuration` | Handles configuration parameters coming from various potential sources.
`stylist.engine` | Core of the style checking tool.
`stylist.fortran` | Rules relating to Fortran source.
`stylist.issue` | Issues found in the source.
`stylist.rule` | None language specific rules.
`stylist.source` | Manages source code in various flavours.
`stylist.style` | Classes relating to styles made up of rules.